==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/nb_NO.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ikke alle kalendere er fullstendig mellomlagret",
"Everything seems to be completely cached" => "Alt ser ut til å være fullstendig mellomlagret",
"No calendars found." => "Ingen kalendere funnet",
"No events found." => "Ingen hendelser funnet",
"Wrong calendar" => "Feil kalender",
"You do not have the permissions to edit this event." => "Du har ikke tilgang til å endre dette eventet",
"The file contained either no events or all events are already saved in your calendar." => "Filen innholden enten ingen hendelser eller alle hendelser er allerede lagret i din kalender.",
"events has been saved in the new calendar" => "hendelser er lagret i den nye kalenderen",
"Import failed" => "Feil med importering",
"events has been saved in your calendar" => "hendelser er lagret i din kalender",
"New Timezone:" => "Ny tidssone:",
"Timezone changed" => "Tidssone endret",
"Invalid request" => "Ugyldig forespørsel",
"Calendar" => "Kalender",
"Deletion failed" => "Sletting feilet",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "gruppe",
"can edit" => "kan endre",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Søndag",
"Monday" => "Mandag",
"Tuesday" => "Tirsdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lørdag",
"Sun." => "Sø.",
"Mon." => "Ma.",
"Tue." => "Ti.",
"Wed." => "On.",
"Thu." => "To.",
"Fri." => "Fr.",
"Sat." => "Lø.",
"January" => "Januar",
"February" => "Februar",
"March" => "Mars",
"April" => "April",
"May" => "Mai",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Desember",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Des.",
"All day" => "Hele dagen ",
"New Calendar" => "Ny kalender",
"Missing or invalid fields" => "Manglende eller ugyldig felt",
"Title" => "Tittel",
"From Date" => "Fra dato",
"From Time" => "Fra tidspunkt",
"To Date" => "Til dato",
"To Time" => "Til tidspunkt",
"The event ends before it starts" => "En hendelse kan ikke slutte før den har begynt.",
"There was a database fail" => "Det oppstod en databasefeil.",
"Birthday" => "Bursdag",
"Business" => "Forretninger",
"Call" => "Ring",
"Clients" => "Kunder",
"Deliverer" => "Leverer",
"Holidays" => "Ferie",
"Ideas" => "Ideér",
"Journey" => "Reise",
"Jubilee" => "Jubileum",
"Meeting" => "Møte",
"Other" => "Annet",
"Personal" => "ersonlig",
"Projects" => "Prosjekter",
"Questions" => "Spørsmål",
"Work" => "Arbeid",
"by" => "av",
"unnamed" => "uten navn",
"You do not have the permissions to update this calendar." => "Du har ikke tilgang til å oppdatere denne kalenderen",
"You do not have the permissions to delete this calendar." => "Du har ikke tilgang til å slette denne kalenderen",
"You do not have the permissions to add to this calendar." => "Du har ikke tilgang til å legge til noe i denne kalenderen",
"You do not have the permissions to add events to this calendar." => "Du har ikke rettigheter til å legge til hendelser i denne kalender.",
"You do not have the permissions to delete this event." => "Du har ikke tilgang til å slette dette eventet",
"Busy" => "Opptatt",
"Does not repeat" => "Gjentas ikke",
"Daily" => "Daglig",
"Weekly" => "Ukentlig",
"Every Weekday" => "Hver ukedag",
"Bi-Weekly" => "Annenhver uke",
"Monthly" => "Månedlig",
"Yearly" => "Årlig",
"never" => "aldri",
"by occurrences" => "etter hyppighet",
"by date" => "etter dato",
"by monthday" => "etter dag i måned",
"by weekday" => "etter ukedag",
"events week of month" => "begivenhetens uke denne måneden",
"first" => "første",
"second" => "andre",
"third" => "tredje",
"fourth" => "fjerde",
"fifth" => "femte",
"last" => "siste",
"by events date" => "etter hendelsenes dato",
"by yearday(s)" => "etter dag i året",
"by weeknumber(s)" => "etter ukenummer/-numre",
"by day and month" => "etter dag og måned",
"Date" => "Dato",
"Cal." => "Kal.",
"Week" => "Uke",
"Month" => "ned",
"Today" => "I dag",
"Settings" => "Innstillinger",
"Share Calendar" => "Del Kalender",
"CalDav Link" => "CalDav-lenke",
"Download" => "Last ned",
"Edit" => "Endre",
"Delete" => "Slett",
"New calendar" => "Ny kalender",
"Edit calendar" => "Rediger kalender",
"Displayname" => "Visningsnavn",
"Calendar color" => "Kalenderfarge",
"Save" => "Lagre",
"Submit" => "Lagre",
"Cancel" => "Avbryt",
"Eventinfo" => "Hendelsesinformasjon",
"Repeating" => "Gjentas",
"Alarm" => "Alarm",
"Attendees" => "Deltakere",
"Share" => "Del",
"Title of the Event" => "Hendelsestittel",
"from" => "fra",
"All Day Event" => "Hele dagen-hendelse",
"Advanced options" => "Avanserte innstillinger",
"Location" => "Sted",
"Edit categories" => "Rediger kategorier",
"Description" => "Beskrivelse",
"Repeat" => "Gjenta",
"Advanced" => "Avansert",
"Select weekdays" => "Velg ukedager",
"Select days" => "Velg dager",
"and the events day of year." => "og hendelsenes dag i året.",
"and the events day of month." => "og hendelsenes dag i måneden.",
"Select months" => "Velg måneder",
"Select weeks" => "Velg uker",
"and the events week of year." => "og hendelsenes uke i året.",
"Interval" => "Intervall",
"End" => "Slutt",
"occurrences" => "forekomster",
"create a new calendar" => "Lag en ny kalender",
"Import a calendar file" => "Importer en kalenderfil",
"Please choose a calendar" => "Vennligst velg en kalender",
"Name of new calendar" => "Navn på ny kalender:",
"Take an available name!" => "Velg at tilgjengelig navn!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "En kalender med dette navnet finnes allerede. Hvis du velger å fortsette vil disse kalenderene bli slått sammen.",
"Remove all events from the selected calendar" => "Fjern alle events fra valgt kalender",
"Import" => "Importer",
"Close Dialog" => "Lukk dialog",
"Create a new event" => "Opprett en ny hendelse",
"Unshare" => "Avslutt deling",
"Shared via calendar" => "Delt via kalender",
"View an event" => "Se på hendelse",
"Category" => "Kategori",
"No categories selected" => "Ingen kategorier valgt",
"of" => "av",
"Access Class" => "Tilgangsklasse",
"From" => "Fra",
"at" => "på",
"To" => "Til",
"Your calendars" => "Dine kalendere",
"General" => "Generellt",
"Timezone" => "Tidssone",
"Update timezone automatically" => "Oppdater tidssone automatisk",
"Time format" => "Tidsformat",
"24h" => "24 t",
"12h" => "12 t",
"Start week on" => "Start uke på",
"Cache" => "Buffer",
"Clear cache for repeating events" => "Fjern gjentagende hendelser fra mellomlager",
"URLs" => "URLs",
"Calendar CalDAV syncing addresses" => "Kalender CalDAV adresser",
"more info" => "mer info",
"Primary address (Kontact et al)" => "Primær adresse (kontakt osv)",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Kun les iCalender link(er)"
);

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/apps/calendar/l10n/nb_NO.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ikke alle kalendere er fullstendig mellomlagret",
"Everything seems to be completely cached" => "Alt ser ut til å være fullstendig mellomlagret",
"No calendars found." => "Ingen kalendere funnet",
"No events found." => "Ingen hendelser funnet",
"Wrong calendar" => "Feil kalender",
"You do not have the permissions to edit this event." => "Du har ikke tilgang til å endre denne hendelsen.",
"The file contained either no events or all events are already saved in your calendar." => "Filen innholden enten ingen hendelser eller alle hendelser er allerede lagret i din kalender.",
"events has been saved in the new calendar" => "hendelser er lagret i den nye kalenderen",
"Import failed" => "Feil med importering",
"events has been saved in your calendar" => "hendelser er lagret i din kalender",
"New Timezone:" => "Ny tidssone:",
"Timezone changed" => "Tidssone endret",
"Invalid request" => "Ugyldig forespørsel",
"Calendar" => "Kalender",
"Deletion failed" => "Sletting feilet",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "gruppe",
"can edit" => "kan endre",
"can share" => "kan dele",
"ddd" => "ddd",
"ddd M/d" => "ddd d.M",
"dddd M/d" => "dddd d.M",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "d [ MMM][ yyyy]{ '–' d MMM yyyy}",
"dddd, MMM d, yyyy" => "dddd d. MMM yyyy",
"Sunday" => "Søndag",
"Monday" => "Mandag",
"Tuesday" => "Tirsdag",
"Wednesday" => "Onsdag",
"Thursday" => "Torsdag",
"Friday" => "Fredag",
"Saturday" => "Lørdag",
"Sun." => "Sø.",
"Mon." => "Ma.",
"Tue." => "Ti.",
"Wed." => "On.",
"Thu." => "To.",
"Fri." => "Fr.",
"Sat." => "Lø.",
"January" => "Januar",
"February" => "Februar",
"March" => "Mars",
"April" => "April",
"May" => "Mai",
"June" => "Juni",
"July" => "Juli",
"August" => "August",
"September" => "September",
"October" => "Oktober",
"November" => "November",
"December" => "Desember",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Des.",
"All day" => "Heldags",
"New Calendar" => "Ny kalender",
"Missing or invalid fields" => "Manglende eller ugyldig felt",
"Title" => "Tittel",
"From Date" => "Fra dato",
"From Time" => "Fra tidspunkt",
"To Date" => "Til dato",
"To Time" => "Til tidspunkt",
"The event ends before it starts" => "En hendelse kan ikke slutte før den har begynt.",
"There was a database fail" => "Det oppstod en databasefeil.",
"Birthday" => "Bursdag",
"Business" => "Forretninger",
"Call" => "Ring",
"Clients" => "Kunder",
"Deliverer" => "Leverer",
"Holidays" => "Ferie",
"Ideas" => "Ideér",
"Journey" => "Reise",
"Jubilee" => "Jubileum",
"Meeting" => "Møte",
"Other" => "Annet",
"Personal" => "Personlig",
"Projects" => "Prosjekter",
"Questions" => "Spørsmål",
"Work" => "Arbeid",
"by" => "av",
"unnamed" => "uten navn",
"You do not have the permissions to update this calendar." => "Du har ikke tilgang til å oppdatere denne kalenderen",
"You do not have the permissions to delete this calendar." => "Du har ikke tilgang til å slette denne kalenderen",
"You do not have the permissions to add to this calendar." => "Du har ikke tilgang til å legge til noe i denne kalenderen",
"You do not have the permissions to add events to this calendar." => "Du har ikke rettigheter til å legge til hendelser i denne kalender.",
"You cannot add non-public events to a shared calendar." => "Du kan ikke legge til private hendelser i en delt kalender.",
"You do not have the permissions to delete this event." => "Du har ikke tilgang til å slette denne hendelsen.",
"Busy" => "Opptatt",
"Show full event" => "Vis hele hendelsen",
"Show only busy" => "Vis kun opptatt",
"Hide event" => "Skjul hendelse",
"Does not repeat" => "Gjentas ikke",
"Daily" => "Daglig",
"Weekly" => "Ukentlig",
"Every Weekday" => "Hver ukedag",
"Bi-Weekly" => "Annenhver uke",
"Monthly" => "Månedlig",
"Yearly" => "Årlig",
"never" => "aldri",
"by occurrences" => "etter hyppighet",
"by date" => "etter dato",
"by monthday" => "etter dag i måned",
"by weekday" => "etter ukedag",
"events week of month" => "begivenhetens uke denne måneden",
"first" => "første",
"second" => "andre",
"third" => "tredje",
"fourth" => "fjerde",
"fifth" => "femte",
"last" => "siste",
"by events date" => "etter hendelsenes dato",
"by yearday(s)" => "etter dag i året",
"by weeknumber(s)" => "etter ukenummer/-numre",
"by day and month" => "etter dag og måned",
"Contact birthdays" => "Kontakters bursdager",
"Date" => "Dato",
"Cal." => "Kal.",
"Day" => "Dag",
"Week" => "Uke",
"Month" => "Måned",
"Today" => "I dag",
"CalDav Link" => "CalDav-lenke",
"Timezone" => "Tidssone",
"Update timezone automatically" => "Oppdater tidssone automatisk",
"Time format" => "Tidsformat",
"24h" => "24 t",
"12h" => "12 t",
"Start week on" => "Start uke på",
"Cache" => "Buffer",
"Clear cache for repeating events" => "Fjern gjentagende hendelser fra mellomlager",
"Primary CalDAV address" => "Primær CalDAV-adresse",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV-adresse",
"Share Calendar" => "Del kalender",
"Download" => "Last ned",
"Edit" => "Endre",
"Delete" => "Slett",
"New calendar" => "Ny kalender",
"Edit calendar" => "Rediger kalender",
"Edit event" => "Rediger hendelse",
"Save event" => "Lagre hendelse",
"Delete event" => "Slett hendelse",
"Eventinfo" => "Hendelsesinformasjon",
"Repeating" => "Gjentas",
"Alarm" => "Alarm",
"Attendees" => "Deltakere",
"Share" => "Del",
"Title of the Event" => "Tittel for hendelsen",
"from" => "fra",
"to" => "til",
"All Day Event" => "Heldagshendelse",
"Advanced options" => "Avanserte innstillinger",
"Location" => "Sted",
"Categories (separate by comma)" => "Kategorier (skill med komma)",
"Edit categories" => "Rediger kategorier",
"Description" => "Beskrivelse",
"Export event" => "Eksporter hendelse",
"Repeat" => "Gjenta",
"Advanced" => "Avansert",
"Select weekdays" => "Velg ukedager",
"Select days" => "Velg dager",
"and the events day of year." => "og hendelsenes dag i året.",
"and the events day of month." => "og hendelsenes dag i måneden.",
"Select months" => "Velg måneder",
"Select weeks" => "Velg uker",
"and the events week of year." => "og hendelsenes uke i året.",
"Interval" => "Intervall",
"End" => "Slutt",
"occurrences" => "forekomster",
"Visibility to people shared with" => "Synlighet til andre delt med",
"create a new calendar" => "Lag en ny kalender",
"Import a calendar file" => "Importer en kalenderfil",
"Please choose a calendar" => "Vennligst velg en kalender",
"Name of new calendar" => "Navn på ny kalender:",
"Take an available name!" => "Velg et tilgjengelig navn!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "En kalender med dette navnet finnes allerede. Hvis du velger å fortsette vil disse kalenderene bli slått sammen.",
"Remove all events from the selected calendar" => "Fjern alle hendelser fra valgt kalender",
"Import" => "Importer",
"Close Dialog" => "Lukk dialog",
"Create a new event" => "Opprett en ny hendelse",
"Create event" => "Lag hendelse",
"Share with user or group" => "Del med bruker eller gruppe",
"Unshare" => "Avslutt deling",
"Not shared with anyone" => "Ikke delt med noen",
"Send Email" => "Send e-post",
"Shared via calendar" => "Delt via kalender",
"Not shared with anyone via calendar" => "Ikke delt med noen via kalender",
"View an event" => "Se på hendelse",
"Category" => "Kategori",
"No categories selected" => "Ingen kategorier valgt",
"%s of %s" => "%s for %s",
"Access Class" => "Tilgangsklasse",
"From" => "Fra",
"at" => "på",
"To" => "Til"
);
